import { z, ZodError, ZodIssueCode} from "zod";
import agendamentoSalaServices from "../services/agendamentoSalaServices.js";
import { sendError, sendResponse } from "../utils/messages.js";

class agendamentoSalaController{
    
    static listar = async(req, res) => {
        try {         
            const agendamento = await agendamentoSalaServices.listar(req.query);

            return sendResponse(res, 200, {
                data: agendamento,
                message: "Agendamentos encontrados com sucesso!"
            });
        } catch (error) {
            console.log(error)

            if (error instanceof z.ZodError) {
                const errorMessages = error.issues.map((issue) => {
                    return {
                        path: issue.path[0],
                        message: issue.message
                    };
                });
                res.status(400).json({
                  error: true,
                  code: 400,
                  message: errorMessages})

            if (error.code && error.message) {
                return sendError(res, error.code, error.message);
              }
              if (error instanceof ZodError) {
                return sendError(res, 404, "Ocorreu um erro ao verificar os paramentos de pesquisa!")
              }
      
              return sendError(res, error.code, error.message)
            }
        }
    }

    static inserir = async (req, res) => {
        try {
            const novoAgendamento = await agendamentoSalaServices.inserir(req.body);

            return sendResponse(res, 201, {data: novoAgendamento});

        } catch (error) {
            console.log(error)
        
        if (error instanceof z.ZodError) {
          const errorMessages = error.issues.map((issue) => {
              return {
                  path: issue.path[0],
                  message: issue.message
              };
          });
          res.status(400).json({
            error: true,
            code: 400,
            message: errorMessages})
        } else {
            if (error instanceof Error && error.name.includes('Prisma')) {
                return sendError(res, 503, "Ocorreu um erro com o banco de dados da aplicação!");
            }
                return sendError(res, error.code, error.message);
            };
        }
    }

    static excluir = async(req, res) => {
        try {            
            
            const agendamentoExcluir = await agendamentoSalaServices.excluir(req.params.id_reserva);

            return sendResponse(res, 200, {
                data: agendamentoExcluir
            });

        } catch (error) {
            console.log(error);
        
        if (error instanceof z.ZodError) {
          const errorMessages = error.issues.map((issue) => {
              return {
                  path: issue.path[0],
                  message: issue.message
              };
          });
          res.status(400).json({
            error: true,
            code: 400,
            message: errorMessages})
        } else {
        if (error instanceof Error && error.name.includes('Prisma')) {
          return sendError(res, 503, "Ocorreu um erro com o banco de dados da aplicação!");
        }
          return sendError(res, error.code, error.message);
        };
        }
    }
}

export default agendamentoSalaController;