import autenticacaoDocenteServices from "../services/autenticacaoDocenteServices.js";
import { sendResponse, sendError } from "../utils/messages.js";
import {z, ZodError} from "zod"

class autenticacaoDocenteController{

    static autenticar = async (req, res) => {
        try{
            const docente =  await autenticacaoDocenteServices.buscarUser(req.body);

            return sendResponse(res,200, {...docente});
        }catch(error){
            console.log(error);
        
            if (error instanceof z.ZodError) {
                const errorMessages = error.issues.map((issue) => {
                    return {
                    path: issue.path[0],
                    message: issue.message
                    };
                });
                res.status(400).json({
                    error: true,
                    code: 400,
                    message: errorMessages
                })
            } else {
                if (error instanceof Error && error.name.includes('Prisma')) {
                return sendError(res, 503, "Ocorreu um erro com o banco de dados da aplicação!");
                }
                return sendError(res, error.code, error.message);
            };
        }
    }
}

export default autenticacaoDocenteController;