import dapeService from "../services/dapeServices.js";
import { z, ZodError, ZodIssueCode } from "zod";
import {sendResponse, sendError} from "../utils/messages.js";

class dapeController{
    static listar = async (req, res) => {

      try {
        const dape = await dapeService.listar(req.query);

        return sendResponse(res, 200, {
          data: dape,
          message: "Usuários dape encontrados com sucesso!"
        });

      } catch (error) {
        console.log(error)

        if (error.code && error.mensage) {
          return sendError(res, error.code, error.mensage);
        }
        if (error instanceof ZodError) {
          return sendError(res, 404, "Ocorreu um erro ao verificar os paramentos de pesquisa!")
        }

        return sendError(res, 500, "Correu erro interno no servidor!")
  
      }
    }


    static listarPorid = async(req, res) => {

      try {
        const dape = await dapeService.listarPorId(req.params);

        return sendResponse(res, 200, {
          data: dape,
          message: "Usuário dape encontrado com sucesso!"
        });

      } catch (error) {
        console.log(error)
        if (error.code && error.message) {
          return sendError(res, error.code, error.message);
        }
  
        if (error instanceof ZodError) {
          return sendError(res, 404, "Ocorreu erros com os parametros!");
        }
  
        if (error instanceof Error && error.name.includes('Prisma')) {
          return sendError(res, 503, "Ocorreu um erro com o banco de dados da aplicação!");
        }
  
        return sendError(res, 500, "Ocorreu um erro interno do servidor!");
  
      }
    }


    static inserir = async (req, res) => {
      try {
        const novoDape = await dapeService.inserir(req.body);

        return sendResponse(res,201, {data: novoDape});
        
      } catch (error) {
        console.log(error)
        if (error.code && error.message) {
          return sendError(res, error.code, error.message);
        }

        if (error instanceof ZodError) {
          return sendError(res, 404, "Ocorreu erros com os parametros!");
        }

        if (error instanceof Error && error.name.includes('Prisma')) {
          return sendError(res, 503, "Ocorreu um erro com o banco de dados da aplicação!");
        }

        return sendError(res, 500, error.message);

       }
    }

    static atualizar = async(req, res) => {
      try {
        const dapeAtualizado = await dapeService.atualizar(req.params, req.body);

        return sendResponse(res, 200, {
          data: dapeAtualizado
        });

      } catch (error) {

        console.log(error);
        
        if (error instanceof z.ZodError) {
          const errorMessages = error.issues.map((issue) => {
              return {
                  path: issue.path[0],
                  message: issue.message
              };
          });
          res.status(400).json({
            error: true,
            code: 400,
            message: errorMessages})
        } else {
        if (error instanceof Error && error.name.includes('Prisma')) {
          return sendError(res, 503, "Ocorreu um erro com o banco de dados da aplicação!");
        }
          return sendError(res, error.code, error.message);
        };

      }
}; 

    static excluir = async(req, res) => {

      try {
        
        const dapeExcluir = await dapeService.excluir(req.params);

        return sendResponse(res, 200, {
          data: dapeExcluir
        });

      } catch (error) {
        
        console.log(error);
        
        if (error instanceof z.ZodError) {
          const errorMessages = error.issues.map((issue) => {
              return {
                  path: issue.path[0],
                  message: issue.message
              };
          });
          res.status(400).json({
            error: true,
            code: 400,
            message: errorMessages})
        } else {
        if (error instanceof Error && error.name.includes('Prisma')) {
          return sendError(res, 503, "Ocorreu um erro com o banco de dados da aplicação!");
        }
          return sendError(res, error.code, error.message);
        };

      }
        
    }
}

export default dapeController;