import bcrypt from "bcryptjs/dist/bcrypt.js";
import docenteServices from "../services/docenteServices.js";
import { sendResponse, sendError } from "../utils/messages.js";
import {z, ZodError} from "zod"
class docenteController{
    static listar = async(req, res) => {

        try {

            const docente = await docenteServices.listar(req.query);

            return sendResponse(res, 200, {
                data: docente,
                message: "Usuários docente encontrados com sucesso!"
            });

        } catch (error) {
            console.log(error)

            if (error.code && error.mensage) {
                return sendError(res, error.code, error.mensage);
            }
            if (error instanceof ZodError) {
                return sendError(res, 404, "Ocorreu um erro ao verificar os paramentos de pesquisa!")
            }

            return sendError(res, 500, "Correu erro interno no servidor!")
      }

    }

    static listarPorId = async(req, res) => {
        try {
            const docente = await docenteServices.listarPorId(req.params);
    
            return sendResponse(res, 200, {
              data: docente,
              message: "Usuário docente encontrado com sucesso!"
            });
    
          } catch (error) {
            console.log(error)
            if (error.code && error.message) {
              return sendError(res, error.code, error.message);
            }
      
            if (error instanceof ZodError) {
              return sendError(res, 404, "Ocorreu erros com os parametros!");
            }
      
            if (error instanceof Error && error.name.includes('Prisma')) {
              return sendError(res, 503, "Ocorreu um erro com o banco de dados da aplicação!");
            }
      
            return sendError(res, 500, "Ocorreu um erro interno do servidor!");
      
          }
    }


    static criar = async(req, res) => {
        try {
            const novoDocente = await docenteServices.inserir(req.body);
    
            return sendResponse(res,201, {data: novoDocente});
            
          } catch (error) {
            console.log(error)
            if (error.code && error.message) {
              return sendError(res, error.code, error.message);
            }
    
            if (error instanceof ZodError) {
              return sendError(res, 404, "Ocorreu erros com os parametros!");
            }
    
            if (error instanceof Error && error.name.includes('Prisma')) {
              return sendError(res, 503, "Ocorreu um erro com o banco de dados da aplicação!");
            }
    
            return sendError(res, 500, error.message);
    
           }
    }

    static atualizar = async (req, res) => {
        try {
        
            const docenteAtualizado = await docenteServices.atualizar(req.params, req.body);
    
            return sendResponse(res, 200, {
              data: docenteAtualizado
            });
    
          } catch (error) {
    
            console.log(error);
            
            if (error instanceof z.ZodError) {
              const errorMessages = error.issues.map((issue) => {
                  return {
                      path: issue.path[0],
                      message: issue.message
                  };
              });
              res.status(400).json({
                error: true,
                code: 400,
                message: errorMessages})
            } else {
            if (error instanceof Error && error.name.includes('Prisma')) {
              return sendError(res, 503, "Ocorreu um erro com o banco de dados da aplicação!");
            }
              return sendError(res, error.code, error.message);
            };
    
          }
    }

    static excluir = async(req, res) => {
        try {
        
            const docenteExcluir = await docenteServices.excluir(req.params);
    
            return sendResponse(res, 200, {
              data: docenteExcluir
            });
    
          } catch (error) {
            
            console.log(error);
            
            if (error instanceof z.ZodError) {
              const errorMessages = error.issues.map((issue) => {
                  return {
                      path: issue.path[0],
                      message: issue.message
                  };
              });
              res.status(400).json({
                error: true,
                code: 400,
                message: errorMessages})
            } else {
            if (error instanceof Error && error.name.includes('Prisma')) {
              return sendError(res, 503, "Ocorreu um erro com o banco de dados da aplicação!");
            }
              return sendError(res, error.code, error.message);
            };
    
        }
    }
}

export default docenteController;