import { z, ZodError, ZodIssueCode} from "zod";
import ensalamentoServices from "../services/ensalamentoServices.js";
import { sendError, sendResponse } from "../utils/messages.js";

class ensalamentoController{
    
    static listar = async(req, res) => {
        try {         
            const ensalamento = await ensalamentoServices.listar(req.query);

            return sendResponse(res, 200, {
                data: ensalamento,
                message: "Ensalamentos encontrados com sucesso!"
            });
        } catch (error) {
            console.log(error)

            if (error instanceof z.ZodError) {
                const errorMessages = error.issues.map((issue) => {
                    return {
                        path: issue.path[0],
                        message: issue.message
                    };
                });
                res.status(400).json({
                  error: true,
                  code: 400,
                  message: errorMessages})

            if (error.code && error.message) {
                return sendError(res, error.code, error.message);
              }
              if (error instanceof ZodError) {
                return sendError(res, 404, "Ocorreu um erro ao verificar os paramentos de pesquisa!")
              }
      
              return sendError(res, error.code, error.message)
            }
        }
    }

    static listarPorId = async (req, res) => {
        try {
            const ensalamento = await ensalamentoServices.listarPorId(req.params.id_ensalamento);

            return sendResponse(res, 200, {
                data: ensalamento,
                message: "Ensalamento encontrado com sucesso!"
            });

        } catch (error) {
            console.log(error)
        if (error.code && error.message) {
          return sendError(res, error.code, error.message);
        }
  
        if (error instanceof ZodError) {
          return sendError(res, 404, "Ocorreu erros com os parametros!");
        }
  
        if (error instanceof Error && error.name.includes('Prisma')) {
          return sendError(res, 503, "Ocorreu um erro com o banco de dados da aplicação!");
        }
  
        return sendError(res, 500, "Ocorreu um erro interno do servidor!");
        }
    }

    static inserir = async (req, res) => {
        try {
            const novoEnsalamento = await ensalamentoServices.inserir(req.body);

            return sendResponse(res, 201, {data: novoEnsalamento});

        } catch (error) {
            console.log(error)
        
        if (error instanceof z.ZodError) {
          const errorMessages = error.issues.map((issue) => {
              return {
                  path: issue.path[0],
                  message: issue.message
              };
          });
          res.status(400).json({
            error: true,
            code: 400,
            message: errorMessages})
        } else {
            if (error instanceof Error && error.name.includes('Prisma')) {
                return sendError(res, 503, "Ocorreu um erro com o banco de dados da aplicação!");
            }
                return sendError(res, error.code, error.message);
            };
        }
    }

    static excluir = async(req, res) => {
        try {
            
            const ensalamentoExcluir = await ensalamentoServices.excluir(req.params.id_ensalamento);

            return sendResponse(res, 200, {
                data: ensalamentoExcluir
            });

        } catch (error) {
            console.log(error);
        
        if (error instanceof z.ZodError) {
          const errorMessages = error.issues.map((issue) => {
              return {
                  path: issue.path[0],
                  message: issue.message
              };
          });
          res.status(400).json({
            error: true,
            code: 400,
            message: errorMessages})
        } else {
        if (error instanceof Error && error.name.includes('Prisma')) {
          return sendError(res, 503, "Ocorreu um erro com o banco de dados da aplicação!");
        }
          return sendError(res, error.code, error.message);
        };
        }
    }
}

export default ensalamentoController;