import { z } from "zod";

class agendamentoSalaSchema {
  
    static listarAgendamento = z.object({
        id_reserva: z.number().min(1).max(200).optional(),
        horario_reserva: z.string().trim().min(1).max(200).optional(),
        data_reserva: z.string().refine((val) => !isNaN(Date.parse(val)), {
            message: "Este campo deve ser do tipo ISO 8601!",
        }).transform((val) => new Date(val)).optional(),
        justificativa: z.string().trim().min(1).max(200).optional(),
        docente_n_siape: z.string().trim().min(1).max(200).optional(),
        sala_id_sala: z.number().min(1).max(200).optional(),
    });

    static listarAgendamentoPorId = z.object({id_reserva: z.preprocess((val) => Number(val), z.number({
        invalid_type_error: "Id informado não é do tipo number.",
    }).int({
        message: "Id informado não é um número inteiro."
    }).positive({
        message: "Id informado não é positivo."
    }))});
  
    static criarAgendamento = z.object({
        horario_reserva: z.string({
            message: "Este campo é obrigatório e deve ser uma string!",
        }).trim().min(1).max(200),
        data_reserva: z.string().refine((val) => !isNaN(Date.parse(val)), {
            message: "Este campo deve ser do tipo ISO 8601!",
        }).transform((val) => new Date(val)),
        justificativa: z.string({
            message: "Este campo deve ser uma string!",
        }).trim().min(1).max(200).optional(),
        docente_n_siape: z.string({
            message: "Este campo é obrigatório e deve ser uma string!",
        }).trim().min(1).max(200),
        sala_id_sala: z.number({
            message: "Este campo é obrigatório e deve ser um número!"
        }).min(1).max(200).optional(),
    });

}

export default agendamentoSalaSchema;