import agendamentoSalaRepository from "../repository/agendamentoSalaRepository.js";
import agendamentoSalaSchema from "../schema/agendamentoSalaSchema.js";
import docenteRepository from "../repository/docenteRepository.js";
import salaRepository from "../repository/salaRepository.js";

class agendamentoSalaServices {

    static async listar(data) {
        const { horario_reserva, data_reserva, justificativa, docente_n_siape, sala_id_sala } = agendamentoSalaSchema.listarAgendamento.parse(data);

        let filtros = {
            where: {
                ... (horario_reserva & { horario_reserva: horario_reserva }),
                ... (data_reserva & { data_reserva: data_reserva }),
                ... (justificativa & { justificativa: justificativa }),
                ... (docente_n_siape & { docente_n_siape: docente_n_siape }),
                ... (sala_id_sala & { sala_id_sala: sala_id_sala }),
            },
            skip: 0,
            take: 10,
        }

        const agendamento = await agendamentoSalaRepository.findAll(filtros);

        if (!agendamento) {
            throw {
                message: "Não foi possivel encontrar nenhum agendamento!",
                code: 404,
            }
        }
        return agendamento;
    }

    static async inserir(data) {

        const { horario_reserva, data_reserva, justificativa, docente_n_siape, sala_id_sala } = agendamentoSalaSchema.criarAgendamento.parse(data);

        const agendamento = {
            data: {
                horario_reserva: horario_reserva,
                data_reserva: data_reserva,
                justificativa: justificativa,
                docente_n_siape: docente_n_siape,
                sala_id_sala: sala_id_sala
            }
        }

        const docenteExist = await docenteRepository.existDocente(docente_n_siape);

        if(!docenteExist){
            throw{
                message: "Não foi possivel encontrar nenhum usuário docente!",
                code: 404,
            }
        }
        
        const salaExist = await salaRepository.findById(sala_id_sala);

        if(!salaExist){
            throw{
                message: "Não foi possivel encontrar nenhuma sala com esse id!",
                code: 404,
            }
        }
        

        let novoAgendamento = await agendamentoSalaRepository.create(agendamento);

        return novoAgendamento;
    }

    static async excluir(id) {

        try {

           const {id_reserva} = agendamentoSalaSchema.listarAgendamentoPorId.parse({id_reserva: id});

            const agendamentoExist = await agendamentoSalaRepository.existAgendamento(id_reserva);

            if(!agendamentoExist || agendamentoExist == null){
                throw ({
                    message:`Agendamento com id ${id_reserva} não existe!`,
                    code: 404
                });
           }

            const agendamentoDeletar = await agendamentoSalaRepository.delete(id_reserva);

            return agendamentoDeletar;
         } catch (error) {
             throw error;
         }
    }
}

export default agendamentoSalaServices;