import dotenv from "dotenv";
import autenticacaoDapeRepository from "../repository/autenticacaoDapeRepository.js";
import authDapeSchema from "../schema/authDapeSchema.js";
import jwt from "jsonwebtoken";
import bcrypt from "bcryptjs";
import { z } from "zod";

dotenv.config();

class autenticacaoDapeServices{
    async buscarUser(id){
        
        const {n_siape_dape, senha_dape} = authDapeSchema.login.parse(id);

        const JWT = process.env.SECRET_KEY;

        const filtros = {
            where: {
                n_siape_dape: n_siape_dape,
            },
        }

        const dapeUser = await autenticacaoDapeRepository.findById(filtros);

        if(!dapeUser){
            throw new z.ZodError([{
                path: ["dape"],
                message: "Dape não existe na base de dados, verifique se o número do siape esta correto!",
                code: z.ZodIssueCode.custom,
                params: {
                    status: 401,
                },
            }]);
        };

        const senhaValida = await bcrypt.compare(senha_dape, dapeUser.senha_dape);
        if(!senhaValida){
            throw new z.ZodError([{
                path: ["dape"],
                message:"Senha informada está incorreta!",
                code: z.ZodIssueCode.custom,
                params: {
                    status: 401,
                  },
            }]);  
        }

        const jwtConfig = {  expiresIn: '30d', algorithm: 'HS256' };

        const token = jwt.sign({ data: {'n_siape_dape': dapeUser.n_siape_dape} }, JWT, jwtConfig);

        return { 
            data:{
                token: token,
                dapeUser: dapeUser, 
            }
        }


    }
}

export default new autenticacaoDapeServices();