import dotenv from "dotenv";
import autenticacaoDocenteRepository from "../repository/autenticacaoDocenteRepository.js";
import authDocenteSchema from "../schema/authDocenteSchema.js"
import jwt from "jsonwebtoken";
import bcrypt from "bcryptjs";
import { z } from "zod";

dotenv.config();

class autenticacaoDocenteServices{
    async buscarUser(id){
        const {n_siape, senha_docente} = authDocenteSchema.login.parse(id);

        const JWT = process.env.SECRET_KEY;

        const filtros = {
            where: {
                n_siape: n_siape,
            },
        }

        const docenteUser = await autenticacaoDocenteRepository.findById(filtros);

        if(!docenteUser){
            throw new z.ZodError([{
                path: ["docente"],
                message: "Docente não existe na base de dados, verifique se o número do siape esta correto!",
                code: z.ZodIssueCode.custom,
                params: {
                    status: 401,
                },
            }]);
        };

        const senhaValida = await bcrypt.compare(senha_docente, docenteUser.senha_docente);
        if(!senhaValida){
            throw new z.ZodError([{
                path: ["docente"],
                message:"Senha informada está incorreta!",
                code: z.ZodIssueCode.custom,
                params: {
                    status: 401,
                  },
            }]);  
        }

        const jwtConfig = {  expiresIn: '30d', algorithm: 'HS256' };

        const token = jwt.sign({ data: {'n_siape': docenteUser.n_siape} }, JWT, jwtConfig);

        return { 
            data:{
                token: token,
                dapeUser: docenteUser, 
            }
        }
    }
}

export default new autenticacaoDocenteServices();