import prisma from "../configs/prismaClient.js";
import dapeRepository from "../repository/dapeRepository.js";
import DapeSchema from "../schema/dapeSchema.js";

class dapeService{
    async listar(data){
        const {
            n_siape_dape,
            nome_dape,
            email_dape,
            senha_dape,
            tipo_usuario,
        } = DapeSchema.listarDape.parse(data);

        let filtros = {
            where: {
                ... (n_siape_dape & {n_siape_dape: n_siape_dape}),
                ... (nome_dape & {nome_dape: nome_dape}),
                ... (email_dape& {email_dape: email_dape}),
                ... (senha_dape & {senha_dape: senha_dape}),
                ... (tipo_usuario & {tipo_usuario: tipo_usuario}),
            },
            skip: 0,
            take: 10,
        }

        const dape = await dapeRepository.findAll(filtros);

        if(!dape){
            throw{
                message: "Não foi possivel encontrar nenhum usuário dape!",
                code: 404,
            }
        }

        return dape;
    }

    async listarPorId(id){
        
        const {n_siape_dape} = DapeSchema.listarDapePorId.parse(id);

        let filtro = {
            where: {
                n_siape_dape: n_siape_dape
            }
        }
        
        let dape = await dapeRepository.findById(filtro);
        console.log(dape);
        

        if(!dape){
            throw{
                code: 404,
                message: `O número do siape ${n_siape_dape} não existe!`
            }
        }

        return dape;

    }

    async inserir(data){

        const { n_siape_dape, nome_dape, email_dape, senha_dape, tipo_usuario } = DapeSchema.criarDape.parse(data);

        const dapeExist = await dapeRepository.findById({
            where: {
                n_siape_dape: n_siape_dape
            }
        });

        if(dapeExist){
            throw{
                message: "Número do siape já está cadastrado!"
            }
        }

        const emailExist = await dapeRepository.dapeExist({
            where: {
                email_dape: email_dape
            }
        });

        if(emailExist){
            throw{
                message: "Email já está cadastrado!"
            }
        }
        
        const dape = {
            data: {
                n_siape_dape: n_siape_dape,
                nome_dape: nome_dape,
                email_dape: email_dape,
                senha_dape: senha_dape,
                tipo_usuario: tipo_usuario
            }
        }

        let novoDape = await dapeRepository.create(dape);

        return novoDape;
    }

    async atualizar(id, data){
        try {
            const zodSchema = DapeSchema.atualizarDape.parse(data);

            const zodId = DapeSchema.listarDapePorId.parse(id);

            const dapeExiste = await dapeRepository.findById({
                where: {
                    n_siape_dape: zodId.n_siape_dape
                }
            });
    
            if (!dapeExiste || dapeExiste == null) {
                throw ({
                    message:`Dape com Número do siape ${zodId.n_siape_dape} não existe!`,
                    code: 404
                });
            }

            const novoDape = await dapeRepository.update(zodId.n_siape_dape, zodSchema);

            return novoDape;

        } catch (error) {
            throw error;
        }
    }

    async excluir(parametros){

        try {
            
            const dadosDape = DapeSchema.listarDapePorId.parse(parametros);

        const dapeExiste = await dapeRepository.findById({
            where: {
                n_siape_dape: dadosDape.n_siape_dape
            }
        });

        if (!dapeExiste || dapeExiste == null) {
            throw ({
                message:`Dape com Número do siape ${dadosDape.n_siape_dape} não existe!`,
                code: 404
            });
        }

        const dapeDeletar = await dapeRepository.delete(dadosDape.n_siape_dape);

        return dapeDeletar;

        } catch (error) {
            throw error;
        }
    }

}

export default new dapeService();