import prisma from "../configs/prismaClient.js";
import docenteRepository from "../repository/docenteRepository.js";
import DocenteSchema from "../schema/docenteSchema.js";

class docenteService{
    async listar(data){
        const {
            n_siape,
            nome_docente,
            email_docente,
            senha_docente,
            turma_docente,
            curso_docente,
            tipo_usuario
        } = DocenteSchema.listarDocente.parse(data);

        let filtros = {
            where: {
                ... (n_siape & {n_siape: n_siape}),
                ... (nome_docente & {nome_docente: nome_docente}),
                ... (email_docente & {email_docente: email_docente}),
                ... (senha_docente & {senha_docente: senha_docente}),
                ... (turma_docente & {curso_docente: curso_docente}),
                ... (tipo_usuario & {tipo_usuario: tipo_usuario}),
            },
            skip: 0,
            take: 10,
        }

        const docente = await docenteRepository.findAll(filtros);

        if(!docente){
            throw{
                message: "Não foi possivel encontrar nenhum usuário docente!",
                code: 404,
            }
        }

        return docente;
    }

    async listarPorId(id){
        const {n_siape} = DocenteSchema.listarDocentePorId.parse(id);

        let filtro = {
            where: {
                n_siape: n_siape
            }
        }
        
        let docente = await docenteRepository.findById(filtro);

        if(!docente){
            throw{
                code: 404,
                message: `O número do siape ${n_siape} não existe!`
            }
        }

        return docente;
    }

    async inserir(data){
        const { n_siape, nome_docente, email_docente, senha_docente, turma_docente, curso_docente, tipo_usuario } = DocenteSchema.criarDocente.parse(data);

        const docenteExist = await docenteRepository.findById({
            where: {
                n_siape: n_siape
            }
        });

        if(docenteExist){
            throw{
                message: "Número do siape já esta cadastrado!"
            }
        }

        const emailExist = await docenteRepository.docenteExist({
            where: {
                email_docente: email_docente
            }
        });
        
        if(emailExist){
            throw{
                message: "Email já esta cadastrado!"
            }
        }
        
        const docente = {
            data: {
                n_siape: n_siape,
                nome_docente: nome_docente,
                email_docente: email_docente,
                senha_docente: senha_docente,
                turma_docente: turma_docente,
                curso_docente: curso_docente,
                tipo_usuario: tipo_usuario
            }
        }

        let novoDocente = await docenteRepository.create(docente);

        return novoDocente;
    }

    async atualizar(id, data){
        try {
            
            const zodSchema = DocenteSchema.atualizarDocente.parse(data);

            const zodId = DocenteSchema.listarDocentePorId.parse(id);

            const docenteExiste = await docenteRepository.findById({
                where: {
                    n_siape: zodId.n_siape
                }
            });
    
            if (!docenteExiste || docenteExiste == null) {
                throw ({
                    message:`Docente com Número do siape ${zodId.n_siape} não existe!`,
                    code: 404
                });
            }

            const novoDocente = await docenteRepository.update(zodId.n_siape, zodSchema);

            return novoDocente;

        } catch (error) {
            throw error;
        }   
    }

    async excluir(parametros){
        try {
            
            const dadosDocente = DocenteSchema.listarDocentePorId.parse(parametros);

        const docenteExiste = await docenteRepository.findById({
            where: {
                n_siape: dadosDocente.n_siape
            }
        });

        if (!docenteExiste || docenteExiste == null) {
            throw ({
                message:`Docente com Número do siape ${dadosDocente.n_siape} não existe!`,
                code: 404
            });
        }

        const docenteDeletar = await docenteRepository.delete(dadosDocente.n_siape);

        return docenteDeletar;

        } catch (error) {
            throw error;
        }
    }
}

export default new docenteService();