import ensalamentoRepository from "../repository/ensalamentoRepository.js";
import dapeRepository from "../repository/dapeRepository.js";
import EnsalamentoSchema from "../schema/ensalamentoSchema.js";
import docenteRepository from "../repository/docenteRepository.js";
import salaRepository from "../repository/salaRepository.js";

class ensalamentoServices{

    async listar(data){
        const {
            id_ensalamento,
            data_inicio_ensalamento,
            data_fim_ensalamento,
            horario_ensalamento,
            repetir,
            dape_n_siape_dape,
            docente_n_siape,
            sala_id_sala
        } = EnsalamentoSchema.listarEnsalamento.parse(data);
        
        let filtros = {
            where: {
                ... (id_ensalamento & {id_ensalamento: id_ensalamento}),
                ... (data_inicio_ensalamento & {data_inicio_ensalamento: data_inicio_ensalamento}),
                ... (data_fim_ensalamento & {data_fim_ensalamento: data_fim_ensalamento}),
                ... (horario_ensalamento & {horario_ensalamento: horario_ensalamento}),
                ... (repetir & {repetir: repetir}),
                ... (dape_n_siape_dape & {dape_n_siape_dape: dape_n_siape_dape}),
                ... (docente_n_siape & {docente_n_siape: docente_n_siape}),
                ... (sala_id_sala & {sala_id_sala: sala_id_sala}),
            },
            skip: 0,
            take: 10,
        }

        const ensalamento = await ensalamentoRepository.findAll(filtros);

        if(!ensalamento){
            throw{
                message: "Não foi possivel encontrar nenhum ensalamento!",
                code: 404,
            }
        }

        return ensalamento;
    
    }

    async listarPorId(id){

        id = parseInt(id)
        const {id_ensalamento} = EnsalamentoSchema.listarEnsalamentoPorId.parse({id_ensalamento: id});

        let ensalamento = await ensalamentoRepository.findById(id_ensalamento);

        if(!ensalamento){
            throw{
                code: 404,
                message: `O id ${id_ensalamento} de ensalamento não existe!`
            }
        }

        return ensalamento;
    }

    async inserir(data){
        console.log(data);
        const {data_inicio_ensalamento, data_fim_ensalamento, horario_ensalamento, repetir, dape_n_siape_dape, docente_n_siape, sala_id_sala} = EnsalamentoSchema.criarEnsalamento.parse(data);

        const ensalamento = {
            data: {
                data_inicio_ensalamento: data_inicio_ensalamento,
                data_fim_ensalamento: data_fim_ensalamento,
                horario_ensalamento: horario_ensalamento,
                repetir: repetir,
                dape_n_siape_dape: dape_n_siape_dape,
                docente_n_siape: docente_n_siape,
                sala_id_sala: sala_id_sala
            }
        }

        const dapeExist = await dapeRepository.existDape(dape_n_siape_dape);

        if(!dapeExist){
            throw{
                message: "Não foi possivel encontrar nenhum usuário dape!",
                code: 404,
            }
        }

        const docenteExist = await docenteRepository.existDocente(docente_n_siape);

        if(!docenteExist){
            throw{
                message: "Não foi possivel encontrar nenhum usuário docente!",
                code: 404,
            }
        }
        
        const salaExist = await salaRepository.findById(sala_id_sala);

        if(!salaExist){
            throw{
                message: "Não foi possivel encontrar nenhuma sala com esse id!",
                code: 404,
            }
        }
        

        let novoEnsalamento = await ensalamentoRepository.create(ensalamento);

        return novoEnsalamento;
    }

    async excluir(id){
        try {
            id = parseInt(id)

           const {id_ensalamento} = EnsalamentoSchema.listarEnsalamentoPorId.parse({id_ensalamento: id});

           const ensalamentoExist = await ensalamentoRepository.findById(id_ensalamento);

           if(!ensalamentoExist || ensalamentoExist == null){
                throw ({
                    message:`Ensalamento com id ${id_ensalamento} não existe!`,
                    code: 404
                });
           }

           const ensalamentoDeletar = await ensalamentoRepository.delete(id_ensalamento);

           return ensalamentoDeletar;
        } catch (error) {
            throw error;
        }
    }


}

export default new ensalamentoServices();