import { parse } from "dotenv";
import salaRepository from "../repository/salaRepository.js";
import SalaSchema from "../schema/salaSchema.js";

class salaServices{
    async listar(data){
        const {
            id_sala,
            nome_sala,
            bloco_sala
        } = SalaSchema.listarSala.parse(data);

        let filtros = {
            where: {
                ... (id_sala & {id_sala: id_sala}),
                ... (nome_sala & {nome_sala: nome_sala}),
                ... (bloco_sala & {bloco_sala: bloco_sala}),
            },
        }

        const sala = await salaRepository.findAll(filtros);

        if(!sala){
            throw{
                message: "Não foi possivel encontrar nenhuma sala!",
                code: 404,
            }
        }

        return sala;
    }
    
    async inserir(data){
        const { nome_sala, bloco_sala } = SalaSchema.criarSala.parse(data);
        
        const sala = {
            nome_sala: nome_sala,
            bloco_sala: bloco_sala
        }

        console.log("dskdjskdjskdj",data)

        let novaSala = await salaRepository.create(sala);

        console.log("dsfdsfkdsfdsf",novaSala)

        return novaSala;
    }

    async atualizar(id, data){
        try {
            const zodSchema = SalaSchema.atualizarSala.parse(data);

            if(id){
                id.id_sala = parseInt(id.id_sala)
            }

            const zodId = SalaSchema.listarSalaPorId.parse(id);

            const salaExiste = await salaRepository.findById(zodId.id_sala);
    
            if (!salaExiste || salaExiste == null) {
                throw ({
                    message:`Sala com id ${id.id_sala} não existe!`,
                    code: 404
                });
            }

            const novaSala = await salaRepository.update(zodId, zodSchema);

            return novaSala;

        } catch (error) {
            throw error;
        }
    }

    async excluir(id){
        try {

            if(id){
                id.id_sala = parseInt(id.id_sala)
            }
            
            const dadosSala = SalaSchema.listarSalaPorId.parse(id);

            const salaExiste = await salaRepository.findById(dadosSala.id_sala);

        if (!salaExiste || salaExiste == null) {
            throw ({
                message:`Sala com id ${dadosSala.id_sala} não existe!`,
                code: 404
            });
        }

        const salaDeletar = await salaRepository.delete(dadosSala.id_sala);

        return salaDeletar;

        } catch (error) {
            throw error;
        }

    }
}

export default new salaServices();