import { describe, expect, it, jest, beforeEach, afterAll, afterEach } from '@jest/globals';
import request from "supertest";
import app from "../../app.js";
import faker from 'faker-br';
import dapeRepository from '../../repository/dapeRepository.js';

jest.mock("../../repository/dapeRepository.js", () => ({
    findAll: jest.fn(),
    create: jest.fn(),
    findById: jest.fn(),
    update: jest.fn(),
    delete: jest.fn(),
    dapeExist: jest.fn(),
}));

describe ('Teste de integração de dape', () => {
    let token;
    console.log("Token:", token);
    let idSiap;

    it("Deve autenticar dape", async () => {
        const dados = await request(app)
        .post('/authdape')
        .send({
            "n_siape_dape": "145732159",
            "senha_dape": "mara1234"
        })
        .set('Accept', 'aplication/json')
        .expect(200);
        token = dados.body.token;
    });

    
    it("Deve ser possivel cadastrar um novo servidor dape", async () => {
        const dados = await request(app)
        .post('/novodape')
        .send({
                n_siape_dape: faker.random.number().toString(),
                nome_dape: "Leo Souza",
                email_dape: "leosouza@gmail.com",
                senha_dape: "leo123456",
                tipo_usuario: "dape"
        })
        .set('Accept', 'aplication/json')
        .set("Authorization", `Bearer ${token}`);
        expect(201);
        
    });
    

    it("Deve listar todos os usuários dape", async () => {

        const mockDape = [
            {
                n_siape_dape: "11077412032",
                nome_dape: "Mara Silva",
                email_dape: "marasilva458@gmail.com",
                senha_dape: "$2a$10$.yY5zliayVHk1BLN294yvO/Mi60pkUqa7d7tfKkwAYiS0wG71nKum",
                tipo_usuario: "dape",
                fotoPerfil: null
            },
            {
                n_siape_dape: "22077412032",
                nome_dape: "Mara Oliveira",
                email_dape: "maraoliveira8@gmail.com",
                senha_dape: "$2a$10$.yY5zliayVHk1BLN294yvO/Mi60pkUqa7d7tfKkwAYiS0wG71nKum",
                tipo_usuario: "dape",
                fotoPerfil: null
            }
    ];

        jest.spyOn(dapeRepository, 'findAll').mockResolvedValue(mockDape);

        const req = await request(app)
        .get('/dape')
        .set('Accept', 'application/json')
        .set("Authorization", `Bearer ${token}`)
        expect(req.body.error).toEqual(false)
        expect(req.status).toBe(200)
        expect(req.body.message).toEqual("Usuários dape encontrados com sucesso!")
        expect(req.body.data).toBeInstanceOf(Array)
        expect(req.body.data.length).toBeGreaterThan(0)
        expect(req.body.data[0].n_siape_dape).toBeDefined()
        expect(req.body.data[0].nome_dape).toBeDefined()
        expect(req.body.data[0].email_dape).toBeDefined()
        expect(req.body.data[0].senha_dape).toBeDefined()
        expect(req.body.data[0].tipo_usuario).toBeDefined()
        expect(req.body.data[0].fotoPerfil).toBeDefined()

        // idSiap=dados.body[0].n_siape_dape;
    
    });

    it("Deve listar usuário dape por ID", async () => {
        const dados = await request(app)
        .get(`/dape/${idSiap}`)
        expect(200);
    });

    it("Deve atualizar dape por id", async () => {
        const n_siape_dape = 154886964;
        const dados = await request(app)
        .patch(`/dape/${n_siape_dape}`)
        .set("Authorization", `Bearer ${token}`)
        .send({
            "nome_dape": "Leo Vieira"
        })
        .expect(200);
    });

    it("Deve excluir dape por id", async () => {
        const n_siape_dape = 154886964;
        const response = await request(app)
        .delete(`/dape/${n_siape_dape}`)
        .set("Authorization", `Bearer ${token}`)
        .set("Content-Type", "application/json")
        expect(response.status).toBe(200);
        expect({error: false}).toHaveProperty('error', false);
    });    
});