import { describe, expect, it, jest, beforeEach, afterAll, afterEach } from '@jest/globals';
import request from "supertest";
import app from "../../app.js";
import faker from 'faker-br';

let userCriado = null

describe("Teste de integração do docente", () => {
    let token;
    let idSiap;

    it("Deve autenticar docente", async () => {
        const dados = await request(app)
        .post('/authdocente')
        .send({
            "n_siape": "4444",
            "senha_docente": "teste"
        })
        .set('Accept', 'aplication/json')
        .expect(200);
        token = dados.body.token;
    });

    it("Deve cadastrar novo docente", async () => {
        const dados = await request(app)
        .post('/novodocente')
        .send({
            n_siape: faker.random.number().toString(),
            nome_docente: "Lucia Menezes",
            email_docente: "luciamenezes123@gmail.com",
            senha_docente: "lucia587",
            turma_docente: "1 B, 2 B",
            curso_docente: "Eletromecânica",
            tipo_usuario: "docente"
        })
        .set('Accept', 'aplication/json')
        .set("Authorization", `Bearer ${token}`)
        expect(201);
        userCriado = dados.body.data
        
    })

    it("Deve listar todos os usuários docentes", async () => {
        const dados = await request(app)
        .get("/docentes")
        .set('Accept', 'aplication/json')
        .set("Authorization", `Bearer ${token}`);
        expect(200);
        
    
    });

    it("Deve listar usuário docente por ID", async () => {
        const dados = await request(app)
        .get(`/docente/${idSiap}`)
        expect(200);
    });

    it("Deve atualizar docente por id", async () => {
        const n_siape = 11008054240;
        const dados = await request(app)
        .patch(`/docente/${n_siape}`)
        .set("Authorization", `Bearer ${token}`)
        .send({
            "nome_docente": "Wesley Vieira"
        })
        .expect(200);
    });

    it("Deve excluir docente por id", async () => {
        const n_siape = userCriado.n_siape;
        const response = await request(app)
        .delete(`/docente/${n_siape}`)
        .set("Authorization", `Bearer ${token}`)
        .set("Content-Type", "application/json")
        expect(response.status).toBe(200);
        expect({error: false}).toHaveProperty('error', false);
    });
});